Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

$#! |
| $.fn
| $.jqplot
| $.jqplot.AxisLabelRenderer
| $.jqplot.AxisTickRenderer
| $.jqplot.BarRenderer
| $.jqplot.BezierCurveRenderer.js
| $.jqplot.BlockRenderer
| $.jqplot.BubbleRenderer
| $.jqplot.CanvasAxisLabelRenderer
| $.jqplot.CanvasAxisTickRenderer
| $.jqplot.CanvasGridRenderer jqplot.canvasGridRenderer.js plugins\jqplot.pyramidGridRenderer.js
| $.jqplot.CanvasOverlay
| $.jqplot.CategoryAxisRenderer
| $.jqplot.ciParser
| $.jqplot.Cursor
| $.jqplot.DateAxisRenderer
| $.jqplot.DivTitleRenderer
| $.jqplot.DonutLegendRenderer
| $.jqplot.DonutRenderer
| $.jqplot.Dragable
| $.jqplot.FunnelLegendRenderer
| $.jqplot.FunnelRenderer
| $.jqplot.Highlighter
| $.jqplot.LinearAxisRenderer
| $.jqplot.LineRenderer
| $.jqplot.LogAxisRenderer
| $.jqplot.MarkerRenderer
| $.jqplot.MekkoAxisRenderer
| $.jqplot.MekkoLegendRenderer
| $.jqplot.MekkoRenderer
| $.jqplot.MeterGaugeRenderer
| $.jqplot.OHLCRenderer
| $.jqplot.PieLegendRenderer
| $.jqplot.PieRenderer
| $.jqplot.PointLabels
| $.jqplot.shadowRenderer
| $.jqplot.shapeRenderer
| $.jqplot.ThemeEngine
| $.jqplot.Trendline
A |
| activeTheme, $.jqplot.ThemeEngine
| addLegendRowHooks, $.jqplot.$.jqplot
| alignTicks, $.jqplot.LinearAxisRenderer
| alpha, $.jqplot.shadowRenderer
| angle $.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer$.jqplot.shadowRenderer
| animate, jqPlot
| animateReplot, jqPlot
| autoscale, Axis
| autoscaleBubbles, $.jqplot.BubbleRenderer
| autoscaleMultiplier, $.jqplot.BubbleRenderer
| autoscalePointsFactor, $.jqplot.BubbleRenderer
| Available Options
| axes, jqPlot
| axesDefaults, jqPlot
| Axis
| axisDefaults, $.jqplot.LogAxisRenderer
B |
| background $.jqplot.MeterGaugeRenderer Grid Legend
| bandData, $.jqplot.LineRenderer
| bands, $.jqplot.LineRenderer
| barDirection, $.jqplot.BarRenderer
| barLabelOptions, $.jqplot.MekkoAxisRenderer
| barLabelRenderer, $.jqplot.MekkoAxisRenderer
| barLabels, $.jqplot.MekkoAxisRenderer
| barMargin, $.jqplot.BarRenderer
| barPadding Global$.jqplot.BarRenderer
| barWidth, $.jqplot.BarRenderer
| baselineColor Global$.jqplot.DateAxisRenderer$.jqplot.LinearAxisRenderer
| baselineWidth Global$.jqplot.DateAxisRenderer$.jqplot.LinearAxisRenderer
| bodyWidth, $.jqplot.OHLCRenderer
| border, Legend
| borderColor $.jqplot.MekkoRenderer Axis Grid
| borderWidth Axis Grid
| breakOnNull, Series
| breakPoints, $.jqplot.LinearAxisRenderer
| breakTickLabel, $.jqplot.LinearAxisRenderer
| bringSeriesToFront, $.jqplot.Highlighter
| bubbleAlpha, $.jqplot.BubbleRenderer
| bubbleGradients, $.jqplot.BubbleRenderer

jQuery namespace to attach functions to jQuery elements.
jQuery function called by the user to create a plot.
Renderer to place labels on the axes.
A “tick” object showing the value of a tick/gridline on the plot.
A plugin renderer for jqPlot to draw a bar plot.
Renderer which draws lines as stacked bezier curves.
Plugin renderer to draw a x-y block chart.
Plugin renderer to draw a bubble chart.
Renderer to draw axis labels with a canvas element to support advanced featrues such as rotated text.
Renderer to draw axis ticks with a canvas element to support advanced featrues such as rotated text.
The default jqPlot grid renderer, creating a grid on a canvas element.
A plugin for jqPlot to render a category style axis, with equal pixel spacing between y data values of a series.
Data Renderer function which converts a custom JSON data object into jqPlot data format.
Plugin class representing the cursor as displayed on the plot.
A plugin for a jqPlot to render an axis as a series of date values.
The default title renderer for jqPlot.
Legend Renderer specific to donut plots.
Plugin renderer to draw a donut chart.
Plugin to make plotted points dragable by the user.
Legend Renderer specific to funnel plots.
Plugin renderer to draw a funnel chart.
Plugin which will highlight data points when they are moused over.
The default jqPlot axis renderer, creating a numeric axis.
The default line renderer for jqPlot, this class has no options beyond the Series class.
A plugin for a jqPlot to render a logarithmic axis.
The default jqPlot marker renderer, rendering the points on the line.
An axis renderer for a Mekko chart.
Legend renderer used by mekko charts with options for controlling number or rows and columns as well as placement outside of plot area.
Draws a Mekko style chart which shows 3 dimensional data on a 2 dimensional graph.
Plugin renderer to draw a meter gauge chart.
jqPlot Plugin to draw Open Hi Low Close, Candlestick and Hi Low Close charts.
Legend Renderer specific to pie plots.
Plugin renderer to draw a pie chart.
Plugin for putting labels at the data points.
The default jqPlot shadow renderer, rendering shadows behind shapes.
The default jqPlot shape renderer.
Theme Engine provides a programatic way to change some of the more common jqplot styling options such as fonts, colors and grid options.
Plugin which will automatically compute and draw trendlines for plotted data.

> this.activeTheme=null

Pointer to currently active theme
called at the end of legend draw, so plugins can add rows to the legend table.

> this.alignTicks = false

true to align tick marks across opposed axes such as from the y2axis to yaxis.

> this.alpha = 0.07

alpha transparency of shadow stroke.

> this.angle = 0

angle of text, measured clockwise from x axis.

> this.angle = 0

angle of text, measured clockwise from x axis.

> this.angle = 45

Angle of the shadow in degrees.

> this.animate = false

True to animate the series on initial plot draw (renderer dependent).

> this.animateReplot = false

True to animate series after a call to the replot() method.

> this.autoscale = false

DEPRECATED the default scaling algorithm produces superior results.

> this.autoscaleBubbles = true

True to scale the bubble radius based on plot size.

> this.autoscaleMultiplier = 1.0

Multiplier the bubble size if autoscaleBubbles is true.

> this.autoscalePointsFactor = -0.07

Factor which decreases bubble size based on how many bubbles on on the chart.
See jqPlot Options for a list of options available thorugh the options object (not complete yet!)

> this.axes = {xaxis: new Axis('xaxis'), yaxis: new Axis('yaxis'), x2axis: new Axis('x2axis'), y2axis: new Axis('y2axis'), y3axis: new Axis('y3axis'), y4axis: new Axis('y4axis'), y5axis: new Axis('y5axis'), y6axis: new Axis('y6axis'), y7axis: new Axis('y7axis'), y8axis: new Axis('y8axis'), y9axis: new Axis('y9axis'), yMidAxis: new Axis('yMidAxis')}

up to 4 axes are supported, each with its own options, See Axis for axis specific options.
default options that will be applied to all axes.
An individual axis object.
Default properties which will be applied directly to the series.

> this.background = "#efefef"

background color of the inside of the gauge.

> this.background = '#fffdf6'

css spec for the background color.

> this.background

css spec for the background of the legend box.

> this.renderer.bandData = []

Data used to draw error bands or confidence intervals above/below a line.
Banding around line, e.g error bands or confidence intervals.

> this.barDirection = 'vertical'

‘vertical’ = up and down bars, ‘horizontal’ = side to side bars

> this.barLabelOptions = {}

options object to pass to the bar label renderer.

> this.barLabelRenderer = $.jqplot.AxisLabelRenderer

renderer to use to draw labels under each bar.

> this.barLabels = this.barLabels || []

array of labels to put under each bar.

> this.barMargin = 10

Number of pixels between groups of bars at adjacent axis values.

> this.barPadding = 10

> this.barPadding = 8

Number of pixels between adjacent bars at the same axis value.

> this.barWidth = null

Width of the bar in pixels (auto by devaul).

> this.baselineColor = null

CSS color spec for the baseline.

> this.baselineColor = null

CSS color spec for the baseline.

> this.baselineColor = null

CSS color spec for the baseline.

> this.baselineWidth = null

width of the baseline in pixels.

> this.baselineWidth = null

width of the baseline in pixels.

> this.baselineWidth = null

width of the baseline in pixels.

> this.bodyWidth = 'auto'

width of the candlestick body in pixels.

> this.border

css spec for the border around the legend box.

> this.borderColor = null

color of the borders between areas on the chart

> this.borderColor = null

color of the border adjacent to the axis.

> this.borderColor = '#999999'

css spec for the color of the grid border.

> this.borderWidth = null

width of line stroked at the border of the axis.

> this.borderWidth = 2.0

width of the border in pixels.

> this.breakOnNull = false

Wether line segments should be be broken at null value.

> this.breakPoints = null

EXPERIMENTAL!!

> this.breakTickLabel = "&asymp

Label to use at the axis break if breakPoints are specified.

> this.bringSeriesToFront = false

This option requires jQuery 1.4+ True to bring the series of the highlighted point to the front of other series.

> this.bubbleAlpha = 1.0

Alpha transparency to apply to all bubbles in this series.

> this.bubbleGradients = false

True to color the bubbles with gradient fills instead of flat colors.
Close